==> e107-0.7.20.tbz: www/e107/e107_plugins/chatbox_menu/languages/English/English.php <==
<?php
/*
+ ----------------------------------------------------------------------------+
|     e107 website system
|
|     Steve Dunstan 2001-2002
|     http://e107.org
|     jalist@e107.org
|
|     Released under the terms and conditions of the
|     GNU General Public License (http://gnu.org).
|
|     $Source: /cvs_backup/e107_0.7/e107_plugins/chatbox_menu/languages/English/English.php,v $
|     $Revision: 11346 $
|     $Date: 2010-02-17 13:56:14 -0500 (Wed, 17 Feb 2010) $
|     $Author: secretr $
+----------------------------------------------------------------------------+
*/

define("CHATBOX_L1", "Unable to accept post as that username is registered - if it is your username please login to post.");
define("CHATBOX_L2", "Chatbox");
define("CHATBOX_L3", "You must be logged in to post comments on this site - please either log in or if you are not registered click <a href='".e_SIGNUP."'>here</a> to signup");
define("CHATBOX_L4", "Submit");
define("CHATBOX_L5", "Reset");
define("CHATBOX_L6", "[blocked by admin]");
define("CHATBOX_L7", "Unblock");
define("CHATBOX_L8", "Info");
define("CHATBOX_L9", "Block");
define("CHATBOX_L10", "Delete");
define("CHATBOX_L11", "No messages yet.");
define("CHATBOX_L12", "View all posts");
define("CHATBOX_L13", "moderate chatbox");
define("CHATBOX_L14", "Emotes");
define("CHATBOX_L15", "Post too long, or empty post submitted");
define("CHATBOX_L16", "Anonymous");
define("CHATBOX_L17", "Duplicate post");
define("CHATBOX_L18", "Chatbox messages moderated");
define("CHATBOX_L19", "You may only post once every ".(FLOODPROTECT ? FLOODTIMEOUT : 'n/a')." seconds");

define("CHATBOX_L20", "Chatbox (all posts)");
define("CHATBOX_L21", "Chat Posts");
define("CHATBOX_L22", "on");
define("CHATBOX_L23", "Error!");
define("CHATBOX_L24", "You do not have the correct permissions to view this page.");
define("CHATBOX_L25", "[ this post has been blocked by admin ]");

// Notify
define("NT_LAN_CB_1", "Chatbox Events");
define("NT_LAN_CB_2", "Message posted");
define("NT_LAN_CB_3", "Posted by");
define("NT_LAN_CB_4", "IP Address");
define("NT_LAN_CB_5", "Message");
define("NT_LAN_CB_6", "Chatbox Message Posted");

?>

==> e107-1.0.3.tbz: www/e107/e107_plugins/chatbox_menu/languages/English/English.php <==
<?php
/*
+ ----------------------------------------------------------------------------+
|     e107 website system
|
|     Copyright (C) 2001-2002 Steve Dunstan (jalist@e107.org)
|     Copyright (C) 2008-2010 e107 Inc (e107.org)
|
|
|     Released under the terms and conditions of the
|     GNU General Public License (http://gnu.org).
|
|     $URL: https://e107.svn.sourceforge.net/svnroot/e107/trunk/e107_0.7/e107_plugins/chatbox_menu/languages/English/English.php $
|     $Revision: 11678 $
|     $Id: English.php 11678 2010-08-22 00:43:45Z e107coders $
|     $Author: e107coders $
+----------------------------------------------------------------------------+
*/

define("CHATBOX_L1", "Unable to accept post as that username is registered - if it is your username please login to post.");
define("CHATBOX_L2", "Chatbox");
define("CHATBOX_L3", "You must be logged in to post comments on this site - please either log in or if you are not registered click <a href='".e_SIGNUP."'>here</a> to signup");
define("CHATBOX_L4", "Submit");
define("CHATBOX_L5", "Reset");
define("CHATBOX_L6", "[blocked by admin]");
define("CHATBOX_L7", "Unblock");
define("CHATBOX_L8", "Info");
define("CHATBOX_L9", "Block");
define("CHATBOX_L10", "Delete");
define("CHATBOX_L11", "No messages yet.");
define("CHATBOX_L12", "View all posts");
define("CHATBOX_L13", "moderate chatbox");
define("CHATBOX_L14", "Emotes");
define("CHATBOX_L15", "Post too long, or empty post submitted");
define("CHATBOX_L16", "Anonymous");
define("CHATBOX_L17", "Duplicate post");
define("CHATBOX_L18", "Chatbox messages moderated");
define("CHATBOX_L19", "You may only post once every ".(FLOODPROTECT ? FLOODTIMEOUT : 'n/a')." seconds");

define("CHATBOX_L20", "Chatbox (all posts)");
define("CHATBOX_L21", "Chat Posts");
define("CHATBOX_L22", "on");
define("CHATBOX_L23", "Error!");
define("CHATBOX_L24", "You do not have the correct permissions to view this page.");
define("CHATBOX_L25", "[ this post has been blocked by admin ]");

// Notify
define("NT_LAN_CB_1", "Chatbox Events");
define("NT_LAN_CB_2", "Message posted");
define("NT_LAN_CB_3", "Posted by");
define("NT_LAN_CB_4", "IP Address");
define("NT_LAN_CB_5", "Message");
define("NT_LAN_CB_6", "Chatbox Message Posted");

?>
